@@ -14,6 +14,11 @@ module Types
           resolver: Resolvers::GroupResolver,
           description: "Find a group"
 
+    field :namespace, Types::NamespaceType,
+          null: true,
+          resolver: Resolvers::NamespaceResolver,
+          description: "Find a namespace"
+
     field :metadata, Types::MetadataType,
           null: true,
           resolver: Resolvers::MetadataResolver,
