@@ -10,8 +10,6 @@
 #    class Foo < ApplicationRecord
 #      include ReactiveCaching
 #
-#      self.reactive_cache_key = ->(thing) { ["foo", thing.id] }
-#
 #      after_save :clear_reactive_cache!
 #
 #      def calculate_reactive_cache
@@ -89,6 +87,8 @@ module ReactiveCaching
     class_attribute :reactive_cache_worker_finder
 
     # defaults
+    self.reactive_cache_key = -> (record) { [model_name.singular, record.id] }
+
     self.reactive_cache_lease_timeout = 2.minutes
 
     self.reactive_cache_refresh_interval = 1.minute
