@@ -164,6 +164,7 @@ class ProjectPolicy < BasePolicy
 
     enable :set_issue_iid
     enable :set_issue_created_at
+    enable :set_issue_updated_at
     enable :set_note_created_at
   end
 
@@ -257,6 +258,7 @@ class ProjectPolicy < BasePolicy
     enable :resolve_note
     enable :create_container_image
     enable :update_container_image
+    enable :destroy_container_image
     enable :create_environment
     enable :create_deployment
     enable :create_release
@@ -445,6 +447,10 @@ class ProjectPolicy < BasePolicy
     prevent :owner_access
   end
 
+  rule { blocked }.policy do
+    prevent :create_pipeline
+  end
+
   private
 
   def team_member?
