@@ -44,7 +44,8 @@ module Gitlab
             human_total_time_spent: issue.human_total_time_spent,
             human_time_estimate: issue.human_time_estimate,
             assignee_ids: issue.assignee_ids,
-            assignee_id: issue.assignee_ids.first # This key is deprecated
+            assignee_id: issue.assignee_ids.first, # This key is deprecated
+            labels: issue.labels
         }
 
         issue.attributes.with_indifferent_access.slice(*self.class.safe_hook_attributes)
